@@ -290,7 +290,7 @@ def print_version(ctx, param, value):
     ctx.exit()
 
 
-@click.group(context_settings=dict(help_option_names=["-h", "--help"]))
+@click.group(context_settings={"help_option_names": ["-h", "--help"]})
 @click.option("--version", is_flag=True, callback=print_version, expose_value=False, is_eager=True)
 @click.option(
     "--config", "-c", type=click.Path(exists=True, dir_okay=False, readable=True), help="Configuration file to use"
@@ -470,6 +470,12 @@ def init(app, project_name, min_version, element_path, force, target_directory):
 @click.option(
     "--ignore-project-source-remotes", is_flag=True, help="Ignore remote source cache servers recommended by projects"
 )
+@click.option(
+    "--retry-failed",
+    "-r",
+    is_flag=True,
+    help="Try to build elements for which a failed build artifact is found",
+)
 @click.argument("elements", nargs=-1, type=click.Path(readable=False))
 @click.pass_obj
 def build(
@@ -480,6 +486,7 @@ def build(
     source_remotes,
     ignore_project_artifact_remotes,
     ignore_project_source_remotes,
+    retry_failed,
 ):
     """Build elements in a pipeline
 
@@ -519,6 +526,7 @@ def build(
             source_remotes=source_remotes,
             ignore_project_artifact_remotes=ignore_project_artifact_remotes,
             ignore_project_source_remotes=ignore_project_source_remotes,
+            retry_failed=retry_failed,
         )
 
 
